@@ -16,12 +16,18 @@ def patch():
 
     # Import for side-effect: configures logging handlers.
     # pylint: disable-msg=W0611
-    import log_settings
+    import log_settings  # noqa
 
     # Monkey-patch django forms to avoid having to use Jinja2's |safe
     # everywhere.
-    import safe_django_forms
-    safe_django_forms.monkeypatch()
+    try:
+        import jingo.monkey
+        jingo.monkey.patch()
+    except ImportError:
+        # If we can't import jingo.monkey, then it's an older jingo,
+        # so we go back to the old ways.
+        import safe_django_forms
+        safe_django_forms.monkeypatch()
 
     # Monkey-patch Django's csrf_protect decorator to use session-based CSRF
     # tokens:
